********
backends
********

.. toctree::

   backend_bases_api.rst
   backend_managers_api.rst
   backend_mixed_api.rst
   backend_tools_api.rst
   backend_gtkagg_api.rst
   backend_qt4agg_api.rst
   backend_qt5agg_api.rst
   backend_wxagg_api.rst
   backend_pdf_api.rst
   backend_svg_api.rst
..   backend_webagg.rst
   dviread.rst
   type1font.rst
